%FILTRADO ADAPTATIVO.
%function pvad=adapfil(ACF,rvad)
%Entradas:
%ACF:coeficientes de autocorrelación.
%rvad:coeficientes de reflexión del vad.
%Salidas:
%pvad:potencia filtrada del vad.
function pvad=adapfil(ACF,rvad)
pvad=sum([1 2 2 2 2 2 2 2 2].*ACF.*rvad);


